searchData={"items":[{"type":"module","title":"CircularBuffer","doc":"Circular Buffer\n\nWhen creating a circular buffer you must specify the max size:\n\n```\ncb = CircularBuffer.new(10)\n```\n\nCircularBuffers are implemented as Okasaki queues like Erlang's `:queue`\nmodule, but with additional optimizations thanks to the reduced set\nof operations.\n\nCircularBuffer implements both the\n[`Enumerable`](https://hexdocs.pm/elixir/Enumerable.html) and\n[`Collectable`](https://hexdocs.pm/elixir/Collectable.html) protocols, so code\nlike the following works:\n\n    iex> cb = Enum.into([1, 2, 3, 4], CircularBuffer.new(3))\n    #CircularBuffer<[2, 3, 4]>\n    iex> Enum.map(cb, fn x -> x * 2 end)\n    [4, 6, 8]","ref":"CircularBuffer.html"},{"type":"function","title":"CircularBuffer.empty?/1","doc":"Checks the buffer to see if its empty\n\nReturns `true` if the given circular buffer is empty, otherwise `false`.","ref":"CircularBuffer.html#empty?/1"},{"type":"function","title":"Examples - CircularBuffer.empty?/1","doc":"iex> cb = CircularBuffer.new(1)\n    iex> CircularBuffer.empty?(cb)\n    true\n    iex> cb |> CircularBuffer.insert(1) |> CircularBuffer.empty?()\n    false","ref":"CircularBuffer.html#empty?/1-examples"},{"type":"function","title":"CircularBuffer.insert/2","doc":"Inserts a new item into the next location of the circular buffer","ref":"CircularBuffer.html#insert/2"},{"type":"function","title":"CircularBuffer.new/1","doc":"Creates a new circular buffer with a given size.","ref":"CircularBuffer.html#new/1"},{"type":"function","title":"CircularBuffer.newest/1","doc":"Returns the newest element in the buffer","ref":"CircularBuffer.html#newest/1"},{"type":"function","title":"Examples - CircularBuffer.newest/1","doc":"iex> cb = CircularBuffer.new(3)\n    iex> CircularBuffer.newest(cb)\n    nil\n    iex> cb = Enum.reduce(1..4, cb, fn n, cb -> CircularBuffer.insert(cb, n) end)\n    iex> CircularBuffer.newest(cb)\n    4","ref":"CircularBuffer.html#newest/1-examples"},{"type":"function","title":"CircularBuffer.oldest/1","doc":"Returns the oldest element in the buffer","ref":"CircularBuffer.html#oldest/1"},{"type":"opaque","title":"CircularBuffer.t/0","doc":"A circular buffer","ref":"CircularBuffer.html#t:t/0"},{"type":"function","title":"CircularBuffer.to_list/1","doc":"Converts a circular buffer to a list. The list is ordered from oldest to newest\nelements based on their insertion order.","ref":"CircularBuffer.html#to_list/1"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.4.2 - Changelog","doc":"* Changes\n  * Fix Elixir 1.19 warnings\n  * Add [REUSE Software](https:/reuse.software/) for machine-readable licensing\n    and copyright information\n  * Minor documentation updates","ref":"changelog.html#v0-4-2"},{"type":"extras","title":"v0.4.1 - Changelog","doc":"* Changes\n  * Documentation and code coverage improvements","ref":"changelog.html#v0-4-1"},{"type":"extras","title":"v0.4.0 - Changelog","doc":"* Changes\n  * Switch from `:queue`-based implementation to list-based one to enable a few\n    optimizations","ref":"changelog.html#v0-4-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}